Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp	(revision 76007)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp	(revision 76008)
@@ -3851,5 +3851,6 @@
 {
     AssertPtrReturnVoid(pMenu);
-    /* Prepare new contents: */
+
+    /* Prepare content: */
     const QList<QSize> sizes = QList<QSize>()
                                << QSize(640, 480)
@@ -3877,5 +3878,5 @@
         QAction *pToggleAction = pMenu->addAction(QApplication::translate("UIActionPool", "Enable", "Virtual Screen"),
                                                   this, SLOT(sltHandleActionTriggerViewScreenToggle()));
-        AssertPtrReturnVoid(pToggleAction);
+        if (pToggleAction)
         {
             /* Configure 'toggle' action: */
@@ -3891,8 +3892,9 @@
     /* Create exclusive 'resize' action-group: */
     QActionGroup *pActionGroup = new QActionGroup(pMenu);
-    AssertPtrReturnVoid(pActionGroup);
+    if (pActionGroup)
     {
         /* Configure exclusive 'resize' action-group: */
         pActionGroup->setExclusive(true);
+
         /* For every available size: */
         foreach (const QSize &size, sizes)
@@ -3901,5 +3903,5 @@
             QAction *pAction = pActionGroup->addAction(QApplication::translate("UIActionPool", "Resize to %1x%2", "Virtual Screen")
                                                                                .arg(size.width()).arg(size.height()));
-            AssertPtrReturnVoid(pAction);
+            if (pAction)
             {
                 /* Configure exclusive 'resize' action: */
@@ -3908,14 +3910,15 @@
                 pAction->setProperty("Requested Size", size);
                 pAction->setCheckable(true);
-                if (screenSize.width() == size.width() &&
-                    screenSize.height() == size.height())
+                if (   screenSize.width() == size.width()
+                    && screenSize.height() == size.height())
                     pAction->setChecked(true);
             }
         }
+
         /* Insert group actions into menu: */
         pMenu->addActions(pActionGroup->actions());
         /* Install listener for exclusive action-group: */
-        connect(pActionGroup, SIGNAL(triggered(QAction*)),
-                this, SLOT(sltHandleActionTriggerViewScreenResize(QAction*)));
+        connect(pActionGroup, &QActionGroup::triggered,
+                this, &UIActionPoolRuntime::sltHandleActionTriggerViewScreenResize);
     }
 }
@@ -3924,33 +3927,38 @@
 {
     AssertPtrReturnVoid(pMenu);
-    /* Get corresponding screen index and size: */
+
+    /* Get corresponding screen index: */
     const int iGuestScreenIndex = pMenu->property("Guest Screen Index").toInt();
 
-    /* Create exclusive action-group: */
+    /* Create exclusive 'remap' action-group: */
     QActionGroup *pActionGroup = new QActionGroup(pMenu);
-    AssertPtrReturnVoid(pActionGroup);
-    {
-        /* Configure exclusive action-group: */
+    if (pActionGroup)
+    {
+        /* Configure exclusive 'remap' action-group: */
         pActionGroup->setExclusive(true);
+
+        /* For every host-screen index: */
         for (int iHostScreenIndex = 0; iHostScreenIndex < m_cHostScreens; ++iHostScreenIndex)
         {
-            QAction *pAction = pActionGroup->addAction(QApplication::translate("UIMultiScreenLayout",
-                                                                               "Use Host Screen %1")
+            /* Create exclusive 'remap' action: */
+            QAction *pAction = pActionGroup->addAction(QApplication::translate("UIMultiScreenLayout", "Use Host Screen %1")
                                                                                .arg(iHostScreenIndex + 1));
-            AssertPtrReturnVoid(pAction);
+            if (pAction)
             {
+                /* Configure exclusive 'remap' action: */
                 pAction->setCheckable(true);
                 pAction->setProperty("Guest Screen Index", iGuestScreenIndex);
                 pAction->setProperty("Host Screen Index", iHostScreenIndex);
-                if (m_mapHostScreenForGuestScreen.contains(iGuestScreenIndex) &&
-                    m_mapHostScreenForGuestScreen.value(iGuestScreenIndex) == iHostScreenIndex)
+                if (   m_mapHostScreenForGuestScreen.contains(iGuestScreenIndex)
+                    && m_mapHostScreenForGuestScreen.value(iGuestScreenIndex) == iHostScreenIndex)
                     pAction->setChecked(true);
             }
         }
+
         /* Insert group actions into menu: */
         pMenu->addActions(pActionGroup->actions());
         /* Install listener for exclusive action-group: */
-        connect(pActionGroup, SIGNAL(triggered(QAction*)),
-                this, SLOT(sltHandleActionTriggerViewScreenRemap(QAction*)));
+        connect(pActionGroup, &QActionGroup::triggered,
+                this, &UIActionPoolRuntime::sltHandleActionTriggerViewScreenRemap);
     }
 }
@@ -3960,14 +3968,14 @@
     AssertPtrReturnVoid(pMenu);
 
-    /* Create exclusive 'scale-factor' action-group: */
+    /* Get corresponding screen index and scale-factor: */
+    const int iGuestScreenIndex = pMenu->property("Guest Screen Index").toInt();
+    const double dCurrentScaleFactor = gEDataManager->scaleFactor(vboxGlobal().managedVMUuid(), iGuestScreenIndex);
+
+    /* Create exclusive 'rescale' action-group: */
     QActionGroup *pActionGroup = new QActionGroup(pMenu);
-    AssertPtrReturnVoid(pActionGroup);
-    {
-        /* Configure exclusive 'scale-factor' action-group: */
+    if (pActionGroup)
+    {
+        /* Configure exclusive 'rescale' action-group: */
         pActionGroup->setExclusive(true);
-
-        /* Get current scale-factor: */
-        const int iGuestScreenIndex = pMenu->property("Guest Screen Index").toInt();
-        const double dCurrentScaleFactor = gEDataManager->scaleFactor(vboxGlobal().managedVMUuid(), iGuestScreenIndex);
 
         /* Get device-pixel-ratio: */
@@ -3985,7 +3993,7 @@
         do
         {
             /* Create exclusive 'scale-factor' action: */
             QAction *pAction = pActionGroup->addAction(QString());
-            AssertPtrReturnVoid(pAction);
+            if (pAction)
             {
                 pAction->setProperty("Guest Screen Index", iGuestScreenIndex);
@@ -4033,6 +4041,6 @@
         pMenu->addActions(pActionGroup->actions());
         /* Install listener for exclusive action-group: */
-        connect(pActionGroup, SIGNAL(triggered(QAction*)),
-                this, SLOT(sltHandleActionTriggerViewScaleFactor(QAction*)));
+        connect(pActionGroup, &QActionGroup::triggered,
+                this, &UIActionPoolRuntime::sltHandleActionTriggerViewRescale);
     }
 }
@@ -3985,7 +3993,7 @@
         do
         {
-            /* Create exclusive 'scale-factor' action: */
+            /* Create exclusive 'rescale' action: */
             QAction *pAction = pActionGroup->addAction(QString());
